@@ -36,7 +36,7 @@
 GPtrArray*
 tracker_data_query_rdf_type (TrackerDataManager  *manager,
                              const gchar         *graph,
-                             gint                 id,
+                             TrackerRowid         id,
                              GError             **error)
 {
 	TrackerDBCursor *cursor = NULL;
@@ -94,7 +94,38 @@ tracker_data_query_rdf_type (TrackerDataManager  *manager,
 	return ret;
 }
 
-gint
+gchar *
+tracker_data_query_resource_urn (TrackerDataManager  *manager,
+                                 TrackerDBInterface  *iface,
+                                 TrackerRowid         id)
+{
+	TrackerDBCursor *cursor = NULL;
+	TrackerDBStatement *stmt;
+	gchar *uri = NULL;
+
+	g_return_val_if_fail (id != 0, NULL);
+
+	stmt = tracker_db_interface_create_statement (iface, TRACKER_DB_STATEMENT_CACHE_TYPE_SELECT, NULL,
+	                                              "SELECT Uri FROM Resource WHERE ID = ?");
+	if (!stmt)
+		return NULL;
+
+	tracker_db_statement_bind_int (stmt, 0, id);
+	cursor = tracker_db_statement_start_cursor (stmt, NULL);
+	g_object_unref (stmt);
+
+	if (!cursor)
+		return NULL;
+
+	if (tracker_db_cursor_iter_next (cursor, NULL, NULL))
+		uri = g_strdup (tracker_db_cursor_get_string (cursor, 0, NULL));
+
+	g_object_unref (cursor);
+
+	return uri;
+}
+
+TrackerRowid
 tracker_data_query_resource_id (TrackerDataManager  *manager,
                                 TrackerDBInterface  *iface,
                                 const gchar         *uri,
@@ -103,7 +134,7 @@ tracker_data_query_resource_id (TrackerDataManager  *manager,
 	TrackerDBCursor *cursor = NULL;
 	TrackerDBStatement *stmt;
 	GError *inner_error = NULL;
-	gint id = 0;
+	TrackerRowid id = 0;
 
 	g_return_val_if_fail (uri != NULL, 0);
 
@@ -134,40 +165,6 @@ tracker_data_query_resource_id (TrackerDataManager  *manager,
 	return id;
 }
 
-gchar *
-tracker_data_query_unused_uuid (TrackerDataManager *manager,
-                                TrackerDBInterface *iface)
-{
-	TrackerDBCursor *cursor = NULL;
-	TrackerDBStatement *stmt;
-	GError *error = NULL;
-	gchar *uuid = NULL;
-
-	stmt = tracker_db_interface_create_statement (iface, TRACKER_DB_STATEMENT_CACHE_TYPE_SELECT, &error,
-	                                              "SELECT SparqlBNODE()");
-
-	if (stmt) {
-		cursor = tracker_db_statement_start_cursor (stmt, &error);
-		g_object_unref (stmt);
-	}
-
-	if (cursor) {
-		if (tracker_db_cursor_iter_next (cursor, NULL, &error)) {
-			uuid = g_strdup (tracker_db_cursor_get_string (cursor, 0, NULL));
-		}
-
-		g_object_unref (cursor);
-	}
-
-	if (G_UNLIKELY (error)) {
-		g_critical ("Could not query resource ID: %s\n", error->message);
-		g_error_free (error);
-	}
-
-	return uuid;
-}
-
-
 TrackerDBCursor *
 tracker_data_query_sparql_cursor (TrackerDataManager  *manager,
                                   const gchar         *query,
@@ -187,3 +184,76 @@ tracker_data_query_sparql_cursor (TrackerDataManager  *manager,
 	return TRACKER_DB_CURSOR (cursor);
 }
 
+gboolean
+tracker_data_query_string_to_value (TrackerDataManager   *manager,
+                                    const gchar          *value,
+                                    const gchar          *langtag,
+                                    TrackerPropertyType   type,
+                                    GValue               *gvalue,
+                                    GError              **error)
+{
+	TrackerData *data;
+	TrackerRowid object_id;
+	gchar *datetime_str;
+	GDateTime *datetime;
+
+	switch (type) {
+	case TRACKER_PROPERTY_TYPE_STRING:
+		g_value_init (gvalue, G_TYPE_STRING);
+		g_value_set_string (gvalue, value);
+		break;
+	case TRACKER_PROPERTY_TYPE_LANGSTRING:
+		g_value_init (gvalue, G_TYPE_BYTES);
+		g_value_take_boxed (gvalue, tracker_sparql_make_langstring (value, langtag));
+		break;
+	case TRACKER_PROPERTY_TYPE_INTEGER:
+		g_value_init (gvalue, G_TYPE_INT64);
+		g_value_set_int64 (gvalue, atoll (value));
+		break;
+	case TRACKER_PROPERTY_TYPE_BOOLEAN:
+		/* use G_TYPE_INT64 to be compatible with value stored in DB
+		   (important for value_equal function) */
+		g_value_init (gvalue, G_TYPE_INT64);
+		g_value_set_int64 (gvalue, g_ascii_strncasecmp (value, "true", 4) == 0);
+		break;
+	case TRACKER_PROPERTY_TYPE_DOUBLE:
+		g_value_init (gvalue, G_TYPE_DOUBLE);
+		g_value_set_double (gvalue, g_ascii_strtod (value, NULL));
+		break;
+	case TRACKER_PROPERTY_TYPE_DATE:
+		g_value_init (gvalue, G_TYPE_INT64);
+		datetime_str = g_strdup_printf ("%sT00:00:00Z", value);
+		datetime = tracker_date_new_from_iso8601 (datetime_str, error);
+		g_free (datetime_str);
+
+		if (!datetime)
+			return FALSE;
+
+		g_value_set_int64 (gvalue, g_date_time_to_unix (datetime));
+		g_date_time_unref (datetime);
+		break;
+	case TRACKER_PROPERTY_TYPE_DATETIME:
+		g_value_init (gvalue, G_TYPE_DATE_TIME);
+		datetime = tracker_date_new_from_iso8601 (value, error);
+
+		if (!datetime)
+			return FALSE;
+
+		g_value_take_boxed (gvalue, datetime);
+		break;
+	case TRACKER_PROPERTY_TYPE_RESOURCE:
+		data = tracker_data_manager_get_data (manager);
+		object_id = tracker_data_update_ensure_resource (data, value, error);
+		if (object_id == 0)
+			return FALSE;
+
+		g_value_init (gvalue, G_TYPE_INT64);
+		g_value_set_int64 (gvalue, object_id);
+		break;
+	case TRACKER_PROPERTY_TYPE_UNKNOWN:
+		g_warn_if_reached ();
+		return FALSE;
+	}
+
+	return TRUE;
+}
