@@ -88,6 +88,7 @@ const TestInfo tests[] = {
 	{ "basic/predicate-variable-4", "basic/data-1", FALSE },
 	{ "basic/urn-in-as", "basic/data-1", FALSE },
 	{ "basic/codepoint-escaping", "basic/data-1", FALSE },
+	{ "basic/long-strings", "basic/data-1", FALSE },
 	{ "bnode/query-1", "bnode/data", FALSE },
 	{ "bnode/query-2", "bnode/data", FALSE },
 	{ "bnode/query-3", "bnode/data", FALSE },
@@ -312,6 +313,17 @@ const TestInfo tests[] = {
 	{ "property-paths/alternative-path-1", "property-paths/data", FALSE },
 	{ "property-paths/alternative-path-2", "property-paths/data", FALSE },
 	{ "property-paths/alternative-path-3", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-1", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-2", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-3", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-4", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-5", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-6", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-7", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-8", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-9", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-10", "property-paths/data", FALSE },
+	{ "property-paths/negated-path-11", "property-paths/data", FALSE },
 	{ "property-paths/mixed-inverse-and-sequence-1", "property-paths/data", FALSE },
 	{ "property-paths/mixed-inverse-and-sequence-2", "property-paths/data", FALSE },
 	{ "property-paths/mixed-inverse-and-sequence-3", "property-paths/data", FALSE },
